import component from "@/utils/component";
import relativeTime from "@/utils/dayjs/relativeTime.js";
import page from "@/utils/page";
import { request } from "@/utils/request";
import { parseScene } from "./utils/util";

wx.WebIM = require("@/utils/webIM/WebIM.js").default;

const dayjs = require("dayjs");
const licia = require("miniprogram-licia");

require("/utils/dayjs/day-zh-cn.js");

dayjs.locale("zh-cn"); // 全局使用
dayjs.extend(relativeTime);

App<IAppOption>({
  globalData: {
    // 测试号 wx2b0bb13edf717c1d
    // dev
    // appid:wxaae50c206446a964
    url: "https://m.takeda.hbraas.com",
    upFileUrl: "https://m.takeda.hbraas.com/",
    imageUrl: "https://m.takeda.hbraas.com/wt/",
    // pro
    // appid:wx1e025040096c7e1d
    // url: "https://m.raredheart.hbsaas.com",
    // upFileUrl: "https://m.raredheart.hbsaas.com/",
    // imageUrl: "https://m.raredheart.hbsaas.com/wt/",

    loginState: "",
    isLogin: 0,
    doctorId: null,

    scene: null,

    needDeal: "",
    caseNav: "0",
    caseStatus: "",
    caseStatusName: "全部",
    newFeedback: "",
  },
  onLaunch() {
    Page = page as WechatMiniprogram.Page.Constructor;
    Component = component as WechatMiniprogram.Component.Constructor;

    wx.ajax = licia.curry(request)({ gUrl: this.globalData.url });

    this.initLogin();

    wx.setInnerAudioOption({
      obeyMuteSwitch: false,
      mixWithOther: false,
    });
  },
  onShow(options) {
    if (options.query.scene) {
      this.globalData.scene = parseScene(options.query.scene);
    }

    const reSourceScene: number[] = [1007, 1008, 1043];
    if (this.globalData.loginState && reSourceScene.includes(options.scene)) {
      this.globalData.loginState = "";
      this.initLogin();
    }
    // this.startLogin();
  },
  initLogin() {
    wx.login({
      success: (res) => {
        wx.ajax({
          method: "GET",
          url: "?r=takeda/user/init-login",
          data: {
            code: res.code,
          },
        }).then((res) => {
          this.globalData.loginState = res.loginState;
          this.globalData.isLogin = res.isLogin;
          this.globalData.doctorId = res.doctorId;
        });
      },
    });
  },
  waitLogin(waitLoginState = false) {
    let time: number;
    return new Promise((resolve, reject) => {
      time = setInterval(() => {
        if (this.globalData.loginState) {
          clearInterval(time);
          if (waitLoginState) {
            resolve(true);
          } else if (this.globalData.isLogin === 0) {
            reject(new Error("未登录"));
            wx.reLaunch({ url: "/module1/pages/login/index" });
          } else if (this.globalData.doctorId === null) {
            this.getApplyDoctor().then((applyDoctorInfo) => {
              if (applyDoctorInfo.AuditStatus === 0) {
                wx.reLaunch({ url: "/module1/pages/setInfoResult/index" });
                reject(new Error("还在审核中"));
              } else {
                wx.reLaunch({ url: "/module1/pages/setInfo/index" });
                reject(new Error("还不是医生"));
              }
            });
          } else {
            resolve(true);
          }
        }
      }, 500);
    });
  },
  getApplyDoctor() {
    return wx.ajax({
      method: "GET",
      url: "?r=takeda/reg/get-apply-doctor",
    });
  },
  getUserInfo(self: WechatMiniprogram.Page.Instance<any, any>, callback?: (res: any) => void) {
    wx.ajax({
      method: "GET",
      url: "?r=takeda/account/info",
      data: {},
    }).then((res) => {
      self.setData({
        userInfo: res,
      });
      callback?.(res);
    });
  },
  getMenuInfo(self) {
    const menuButtonInfo = wx.getMenuButtonBoundingClientRect();
    self.setData({
      menuButtonInfo,
    });
  },
  mpBehavior(data: object) {
    wx.ajax({
      method: "POST",
      url: "?r=takeda/mp-behavior/add",
      data,
      loading: false,
      showMsg: false,
    }).then((_res) => {
      // console.log('res: ', _res)
    });
  },
});
