const app = getApp<IAppOption>();

// pages/story/a.ts
Component({
  /**
   * 组件的属性列表
   */
  properties: {
    // 是否获取用户头像
    chooseAvatar: {
      type: Boolean,
      value: false,
    },
    // 从聊天记录选择问就爱你
    chooseMessage: {
      type: Boolean,
      value: false,
    },
    accept: {
      type: String,
      value: 'image',
    },
    // 是否编辑图片,只对图片生效
    obscure: {
      type: Boolean,
      value: false,
    },
    // 是否显示引导用户编辑图片引导
    edit: {
      type: Boolean,
      value: false,
    },
  },

  /**
   * 组件的初始数据
   */
  data: {
    show1: false,
    fileTypeList: {
      image: 1,
      audio: 2,
      video: 3,
      pdf: 4,
      doc: 5,
      docx: 5,
      xls: 6,
      xlsx: 6,
      ppt: 7,
    },
    cacheEditParams: {},
  },

  /**
   * 组件的方法列表
   */
  methods: {
    GetExtensionFileName(pathfilename: string) {
      const reg = /(\\+)/g;
      const pString = pathfilename.replace(reg, '#'); //用正则表达式来将\或\\替换成#
      const arr = pString.split('#'); // 以“#”为分隔符，将字符分解为数组 例如 D Program Files bg.png
      const lastString = arr[arr.length - 1]; //取最后一个字符
      const arr2 = lastString.split('.'); //   再以"."作为分隔符
      return arr2[arr2.length - 1]; //将后缀名返回出来
    },
    handleAfterRead(e: any, editEnd = false) {
      const file = { tempFilePath: e.detail.file.url, fileType: e.detail.file.type, ...e.detail.file };
      if (this.data.edit && !editEnd) {
        this.setData({
          show1: true,
          cacheEditParams: e,
        });
        return;
      }
      if (this.data.obscure && file.type === 'image') {
        wx.editImage({
          src: file.tempFilePath,
          success: (res: any) => {
            this.uploadFile({
              ...file,
              tempFilePath: res.tempFilePath,
            }).then((res) => {
              this.triggerEvent('file', res as object);
            });
          },
          fail: (err) => {
            if (err.errMsg.includes('开发者工具')) {
              this.uploadFile(file).then((res) => {
                this.triggerEvent('file', res as object);
              });
            }
          },
        });
      } else {
        this.uploadFile(file).then((res) => {
          this.triggerEvent('file', res as object);
        });
      }
    },
    handleEditEnd() {
      this.setData({
        show1: false,
      });
      this.handleAfterRead(this.data.cacheEditParams, true);
    },
    handleChooseAvatar(e: any) {
      this.uploadFile({
        fileType: 'image',
        tempFilePath: e.detail.avatarUrl,
        size: 0,
      }).then((res) => {
        this.triggerEvent('file', res as object);
      });
    },
    handleChooseFile() {
      wx.chooseMessageFile({
        type: 'file',
        count: 1,
        success: (res) => {
          this.uploadFile({
            ...res.tempFiles[0],
            fileType: res.tempFiles[0].type,
            tempFilePath: res.tempFiles[0].path,
          }).then((res) => {
            this.triggerEvent('file', res as object);
          });
        },
        fail() {
          wx.showToast({
            icon: 'none',
            title: '取消选择',
          });
        },
      });
    },
    uploadFile(item: { tempFilePath: string; fileType: string; size: number; name?: string; duration?: number }) {
      const { fileTypeList } = this.data;
      wx.showLoading({
        title: '正在上传',
      });
      return new Promise((resolve, reject) => {
        let url = `${app.globalData.upFileUrl}?r=file-service/upload-`;
        if (item.fileType === 'image') {
          url += 'img';
        } else if (item.fileType === 'video') {
          url += 'video';
        } else if (item.fileType === 'audio') {
          url += 'audio';
        } else {
          url += 'doc';
        }
        wx.uploadFile({
          filePath: item.tempFilePath,
          name: 'file',
          url,
          success: (res) => {
            wx.hideLoading();
            const data = JSON.parse(res.data);
            const suffix = this.GetExtensionFileName(data.data.Url);
            const expandJson = {
              fileId: '',
              name: item.name || `病历相关文件.${suffix}`,
              size: (item.size / 1024).toFixed(2),
              fileUrl: data.data.Url,
              imgUrl: '',
              suffix,
              type: item.fileType,
              duration: 0,
              hash: '',
              fileType: fileTypeList[suffix] || 99,
            };
            if (item.fileType === 'image') {
              expandJson.fileType = fileTypeList.image;
              expandJson.imgUrl = data.data.Url;
            } else if (item.fileType === 'video') {
              expandJson.fileType = fileTypeList.video;
              expandJson.imgUrl = data.data.SnapshotUrl;
            } else if (item.fileType === 'audio') {
              expandJson.fileType = fileTypeList.audio;
              expandJson.duration = item.duration ? Number.parseInt(String(item.duration / 1000)) : 0;
            }
            resolve(expandJson);
          },
          fail() {
            wx.hideLoading();
            reject(new Error('上传失败'));
          },
        });
      });
    },
  },
});

export {};
