const app = getApp<IAppOption>();

// pages/story/a.ts
Component({
  /**
   * 组件的属性列表
   */
  properties: {
    userInfo: Object,
    DoctorTitleType: Object,
    hospitalClassification: Object,
    hospitalLevel: Object,
  },

  /**
   * 组件的初始数据
   */
  data: {
    fold1: false,
    foldHeight1: 10000,
    take: {},
    case: {},
    cooperateList: [],

    tips: {
      tipDealCase: 2, //是否待处理病历提醒,1-是，2-否
      tipCaseUpdate: 2, //是否病历更新提醒,1-是，2-否
      tipChatRoom: 2, //是否聊天室消息提醒,1-是，2-否
      tipDoctorWaitAudit: 2, //是否待审核医生提醒,1-是，2-否
      tipDoctorAudit: 2, //是否审核提醒，1-是，2-否
    },

    guide: 0,
    guideShow: false,
    guideList: ["1-1", "1-2", "1-3"],
  },

  lifetimes: {
    attached() {
      app.waitLogin(true).then(() => {
        this.getTake();
        this.getCase();
        this.getCooperate();
        this.getTips();
        this.getGuide();
      });
    },
  },
  /**
   * 组件的方法列表
   */
  methods: {
    getHeight() {
      const query = wx.createSelectorQuery().in(this);
      query.select("#fold1").boundingClientRect();
      query.exec((res) => {
        this.setData({
          foldHeight1: res[0].height,
        });
      });
    },
    toggleFold1() {
      app.mpBehavior({ PageName: "BTN_MYDOCTORSTOGGLE" });
      this.setData({
        fold1: !this.data.fold1,
      });
    },
    handleEntryCase() {
      app.mpBehavior({ PageName: "BTN_SUBMITEMPTYCASE" });
      wx.navigateTo({
        url: "/module1/pages/entryCases/index",
      });
    },
    getTake() {
      wx.ajax({
        method: "GET",
        url: "?r=takeda/doctor/todo",
        data: {},
      }).then((res) => {
        this.setData({
          take: res,
        });
      });
    },
    getCase() {
      wx.ajax({
        method: "GET",
        url: "?r=takeda/doctor/case",
        data: {},
      }).then((res) => {
        this.setData({
          case: res,
        });
      });
    },
    getCooperate() {
      wx.ajax({
        method: "GET",
        url: "?r=takeda/doctor/cooperation-doctor-list",
        data: {},
      }).then((res) => {
        this.setData({
          cooperateList: res.list,
        });
        this.getHeight();
      });
    },
    handleCaseUpdate() {
      app.mpBehavior({ PageName: "BTN_CASEUPDATE" });
      app.globalData.newFeedback = "1";
      wx.switchTab({
        url: "/pages/cases/index",
      });
    },
    handleChat() {
      app.mpBehavior({ PageName: "BTN_LEARNINGMESSAGE" });
      wx.switchTab({
        url: "/pages/chatRoomList/index",
      });
    },
    handleQuestion(e) {
      const { index } = e.currentTarget.dataset;
      this.triggerEvent("question", index);
    },
    handleCase(e) {
      const { type } = e.currentTarget.dataset;
      const name = {
        0: "全部",
        2: "新病历",
        3: "讨论中",
        4: "已归档",
      }[type];
      const PageName = {
        0: "BTN_MANAGEDCASESALL",
        2: "BTN_MANAGEDCASESNEW",
        3: "BTN_MANAGEDCASESDISCUSSING",
        4: "BTN_MANAGEDCASESCLOSED",
      }[type];
      app.mpBehavior({ PageName });
      app.globalData.caseStatus = type === "0" ? "" : type;
      app.globalData.caseStatusName = name;
      wx.switchTab({
        url: "/pages/cases/index",
      });
    },
    handleCooperateDetail(e) {
      const { index } = e.currentTarget.dataset;
      this.selectComponent(`#cooperate${index}`).handleDetail();
    },
    handleApplication() {
      wx.navigateTo({
        url: "/module1/pages/applicationRecords/index",
      });
    },
    handleApplicationDoctor() {
      app.mpBehavior({ PageName: "BTN_MYDOCTORSBIND" });
      wx.navigateTo({
        url: "/module1/pages/setApplicationDoctor/index",
      });
    },

    getTips() {
      wx.ajax({
        method: "GET",
        url: "?r=takeda/doctor/get-tips",
        data: {},
      }).then((res) => {
        this.setData({
          tips: res,
        });
      });
    },

    getGuide() {
      wx.ajax({
        method: "GET",
        url: "?r=takeda/account/get-guide",
        data: {},
      }).then((res) => {
        this.setData({
          guideShow: res.tipStatus === 2,
        });
      });
    },
    touchmovePreview() {
      return false;
    },
    handleTapPreview() {
      if (this.data.guide === this.data.guideList.length - 1) {
        this.setData({
          guideShow: false,
        });
        this.handleGuideClose();
      }
      this.setData({
        guide: Number(this.data.guide) + 1,
      });
    },
    handleGuideClose() {
      this.setData({
        guideShow: false,
      });
      wx.ajax({
        method: "POST",
        url: "?r=takeda/account/close-guide",
        data: {},
      });
    },
  },
});

export {};
