const app = getApp<IAppOption>();

Page({
  data: {
    rid: "",
    show1: false,
    isOpen: 2,

    caseId: "",
    images: [] as any,
    info: "",
    audios: [] as any,
    files: [] as any,

    DoctorLevel: 1,

    auth: {} as any,

    DeleteAttachmentIds: [] as any,
  },
  onLoad(options) {
    this.setData({
      caseId: options.id,
      rid: options.rid,
    });
    app.waitLogin().then(() => {
      app.mpBehavior({ PageName: "PG_SUBMITFEEDBACK" });
      this.getCache();
      app.getUserInfo(this, (res) => {
        this.setData({
          DoctorLevel: res.DoctorLevel,
        });
      });
      this.getAuth();
    });
  },
  getAuth() {
    wx.ajax({
      method: "GET",
      url: "?r=takeda/case/get-case-detail-op-auth",
      data: { caseId: this.data.caseId },
    }).then((res) => {
      this.setData({
        auth: res,
      });
    });
  },
  handleMapPhoto() {
    app.mpBehavior({ PageName: "BTN_FEEDBACKSELECTIMAGE" });
  },
  handleMedia(e) {
    const detail = e.detail;
    const images = this.data.images;
    this.setData({
      images: [
        ...images,
        {
          name: detail.name,
          url: detail.fileType == 3 ? detail.imgUrl : detail.fileUrl,
          isRepeat: 2,
          hash: '',
          fileType: detail.fileType,
          videoUrl: detail.fileType == 3 ? detail.fileUrl : '',
        },
      ],
    });
    if (detail.fileType == 1) {
      this.imageVerify(detail.fileUrl);
    }
    this.handleCache();
  },
  handleDelPhoto(e) {
    const { index } = e.currentTarget.dataset;
    const { images, DeleteAttachmentIds } = this.data;
    if (images[index].attachmentId) {
      DeleteAttachmentIds.push(images[index].attachmentId);
    }
    this.setData({
      images: this.data.images.filter((_, i) => i !== Number(index)),
      DeleteAttachmentIds,
    });
    this.handleCache();
  },
  imageVerify(url: string) {
    const { images, DeleteAttachmentIds } = this.data;
    const LastImagesHash: any = [];
    images.forEach((item) => {
      if (item.hash) {
        LastImagesHash.push(item.hash);
      }
    });
    wx.ajax({
      method: "POST",
      url: "?r=takeda/common/image-verify",
      data: {
        ImageUrl: url,
        LastImagesHash,
        DeleteAttachmentIds,
      },
    }).then((res) => {
      const index = images.findIndex((item) => item.url === url);
      const imageItem = images[index];
      if (res.Hash) {
        imageItem.hash = res.Hash;
      }
      if (res.code === 1001) {
        wx.showToast({
          title: res.msg,
          icon: "none",
        });
        imageItem.repeat = true;
      }
      this.setData({
        images,
      });
    });
  },
  handleMapAudio() {
    app.mpBehavior({ PageName: "BTN_FEEDBACKRECORDLONGPRESS" });
  },
  handleAudio(e) {
    this.setData({
      audios: [
        ...this.data.audios,
        {
          name: e.detail.name,
          url: e.detail.fileUrl,
          duration: e.detail.duration,
          isRepeat: 2,
        },
      ],
    });
    this.handleCache();
  },
  handleDelAudio(e) {
    wx.showModal({
      title: "确认删除?",
      confirmColor: "#00B4C5",
      cancelColor: "#141515",
      success: (res) => {
        if (res.confirm) {
          const { index } = e.currentTarget.dataset;
          this.setData({
            audios: this.data.audios.filter((_, i) => i !== Number(index)),
          });
          this.handleCache();
        }
      },
    });
  },
  handleMapFile() {
    app.mpBehavior({ PageName: "BTN_FEEDBACKSELECTFILE" });
  },
  handleFile(e) {
    this.setData({
      files: [
        ...this.data.files,
        {
          fileType: e.detail.fileType,
          name: e.detail.name,
          url: e.detail.fileUrl,
          size: e.detail.size,
          isRepeat: 2,
          videoUrl: e.detail.videoUrl,
          duration: e.detail.duration,
        },
      ],
    });
    this.handleCache();
  },
  handleDelFile(e) {
    wx.showModal({
      title: "确认删除?",
      confirmColor: "#00B4C5",
      cancelColor: "#141515",
      success: (res) => {
        if (res.confirm) {
          const { index } = e.currentTarget.dataset;
          this.setData({
            files: this.data.files.filter((_, i) => i !== Number(index)),
          });
          this.handleCache();
        }
      },
    });
  },
  handlePreviewFile(e) {
    const { index } = e.currentTarget.dataset;
    const item = this.data.files[index];
    wx.downloadFile({
      url: item.url,
      success(res) {
        wx.openDocument({
          filePath: res.tempFilePath,
          fail() {
            wx.showToast({
              title: "该文件无法预览",
              icon: "none",
            });
          },
        });
      },
    });
  },
  handlePreviewName(e) {
    const { index } = e.currentTarget.dataset;
    const item = this.data.files[index];
    wx.showModal({
      title: "文件名",
      content: item.name,
      confirmColor: "#00B4C5",
      cancelColor: "#141515",
      showCancel: false,
      confirmText: "关闭",
    });
  },
  handleDownloadFile(e) {
    const { index } = e.currentTarget.dataset;
    const item = this.data.files[index];
    wx.downloadFile({
      url: item.url,
      success(res) {
        if (res.statusCode === 200) {
          wx.hideLoading();
          const tempFilePath = res.tempFilePath;
          const FileSystemManager = wx.getFileSystemManager();
          FileSystemManager.saveFile({
            tempFilePath,
            success() {
              wx.showToast({
                title: "下载成功",
                icon: "none",
                mask: true,
              });
            },
            fail() {
              wx.showToast({
                title: "下载失败，请重新尝试",
                icon: "none",
                mask: true,
              });
            },
          });
        }
      },
    });
  },
  formatParams() {
    const { images, info, audios, files } = this.data;
    return { images: JSON.stringify(images), info, audios: JSON.stringify(audios), files: JSON.stringify(files) };
  },
  onClose() {
    this.setData({
      show1: false,
    });
  },
  handleTogleOpen() {
    this.setData({
      isOpen: this.data.isOpen === 1 ? 2 : 1,
    });
  },
  handleSave() {
    const { images, audios, files, info, auth } = this.data;
    if (images.length === 0 && audios.length === 0 && files.length === 0 && !info) {
      wx.showToast({
        title: "请填写或上传反馈信息",
        icon: "none",
      });
      return;
    }
    if (!auth.canFeedbackInvite && !auth.canFeedbackOpen) {
      this.handleSubmit();
    } else {
      this.setData({
        show1: true,
      });
    }
  },
  handleBack() {
    app.mpBehavior({ PageName: "BTN_FEEDBACKBACK" });
    wx.navigateBack();
  },
  handleSubmit() {
    const { caseId, isOpen, rid } = this.data;
    app.mpBehavior({ PageName: "BTN_FEEDBACKSAVE" });
    const params = this.formatParams();
    wx.ajax({
      method: "POST",
      url: "?r=takeda/case/add-feedback",
      data: {
        ...params,
        caseId,
        isOpen,
      },
    }).then((res) => {
      wx.reLaunch({
        url: `/module1/pages/entryCasesResult/index?isf=${res.isSubscribe}&wxi=${encodeURIComponent(res.wxImg)}&cid=${res.caseId || caseId}&rid=${rid}`,
      });
    });
  },
  handleInvite() {
    const { caseId, isOpen, rid } = this.data;
    const params = this.formatParams();
    wx.navigateTo({
      url: `/module1/pages/setCaseDoctor/index`,
      success: (res) => {
        res.eventChannel.emit("acceptDataFromOpenerPage", {
          params: {
            ...params,
            isOpen,
          },
          caseId,
          rid,
          feedBackInvite: true,
        });
      },
    });
  },
  getCache() {
    const { caseId } = this.data;
    wx.ajax({
      method: "GET",
      url: "?r=takeda/case/get-feedback-cache",
      data: {
        caseId,
      },
    }).then((res) => {
      this.setData({
        images: res.images,
        info: res.info,
        audios: res.audios,
        files: res.files,
      });
    });
  },
  handleCache() {
    const { caseId, images, info, audios, files } = this.data;
    const cacheParams = {
      caseId,
      images: JSON.stringify(images),
      info: `${info}`,
      audios: JSON.stringify(audios),
      files: JSON.stringify(files),
    };
    wx.ajax({
      method: "POST",
      url: "?r=takeda/case/save-feedback-cache",
      data: cacheParams,
      showMsg: false,
    });
  },
  handlePreviewMedia(e) {
    const { index } = e.currentTarget.dataset;
    const { images } = this.data;
    const sources = images.reduce((pre, cur) => {
      return [
        ...pre,
        {
          url: cur.fileType === 3 ? cur.videoUrl : cur.url,
          type: cur.fileType === 3 ? 'video' : 'image',
        },
      ];
    }, []);
    wx.previewMedia({
      sources,
      current: index,
    });
  },
});

export {};
