import dayjs from "dayjs";

const app = getApp<IAppOption>();

interface IMessageItem {
  msgId: string;
  contentType: "1" | "2" | "3" | "4" | "5" | "6" | "7"; //  1:文本  2: 语音 3. 图片 4. 视频 5. 提示信息 6. 撤回消息 7. 病例卡片
  content: any;
  fromDoctorId: string;
  doctorImg: string;
  createTime: string;
  createTimeName?: string;
  isSelf: 1 | 2;
  isRead: 1 | 2;
  doctorName: string;
  hospitalName: string;
  showTime?: boolean;
  isPlay?: boolean;
  uniqueCode?: string;
  longpress?: boolean;
}

Page({
  data: {
    id: "",

    show1: false,
    show2: false,
    show3: false,

    focus: false,
    fold: true,
    scrollTop: 0,
    scrollIntoView: "",
    doctorDetail: {} as any,

    roomDoctors: [],
    newRoomDoctors: [],
    case: {} as any,
    chatGroupInfo: {} as any,
    chatDoctor: {} as any,

    isLoad: false,
    isFinish: false,
    messageList: [] as IMessageItem[],
    lastMsgId: "",
    unReadCount: 0,

    userInfo: {} as any,

    sendMessage: "",
    videoUrl: "",

    protocol: `<p><span style="color: rgb(38, 38, 38); font-size: 14px;">罕心守护平台向用户提供了“学习窗”功能，基于此服务，我们在此特别声明：</span></p><p><span style="color: rgb(38, 38, 38); font-size: 14px;">罕心守护平台非常重视您的个人信息保护及平台信息的隐私性，您同意在学习窗功能使用时遵守以下规则：</span></p><p><span style="color: rgb(38, 38, 38); font-size: 14px;"> </span></p><p><span style="color: rgb(38, 38, 38); font-size: 14px;">1.严禁在学习窗内讨论或分享任何患者的个人身份信息，包括但不限于姓名、性别等。群内发送的任何素材内容，必须去除所有可能识别患者身份的敏感信息；</span></p><p><span style="color: rgb(38, 38, 38); font-size: 14px;">2.不以截图、录音或以任何形式将内容传播；</span></p><p><span style="color: rgb(38, 38, 38); font-size: 14px;">3.讨论内容仅限于专业交流，不得用于任何商业目的; </span></p><p><span style="color: rgb(38, 38, 38); font-size: 14px;">4.保持讨论的专业性和尊重性，避免使用侮辱性或攻击性语言。</span></p><p><br></p>`,

    record: true,

    canInvite: false,

    sliderTop: 0,

    // caseDetail
    caseFold: false,
    detail: {} as any,
  },
  innerAudioContext: null as WechatMiniprogram.InnerAudioContext | null,
  videoContext: null as WechatMiniprogram.VideoContext | null,
  onLoad(options) {
    const systemInfo = wx.getSystemInfoSync();
    this.setData({
      id: options.id,
      sliderTop: systemInfo.screenHeight - 260,
    });
    this.videoContext = wx.createVideoContext("video");
    this.innerAudioContext = wx.createInnerAudioContext({
      useWebAudioImplement: true,
    });
    app.waitLogin().then(() => {
      this.getAgree();

      app.getUserInfo(this);
    });
  },
  onUnload() {
    wx.WebIM.conn.close();
    if (this.innerAudioContext) {
      this.innerAudioContext.stop();
    }
    if (this.videoContext) {
      this.videoContext.stop();
    }
  },
  init() {
    this.getMessageList();
    this.getDetail();
  },
  getInvite() {
    wx.ajax({
      method: "GET",
      url: "?r=takeda/chat/get-invite-doctor-list",
      data: { count: 1, caseId: this.data.case.caseId },
    }).then((res) => {
      this.setData({
        canInvite: res.canInvite === 1,
      });
    });
  },
  getAgree() {
    wx.ajax({
      method: "GET",
      url: "?r=takeda/account/chat-room-notice",
      data: {
        roomId: this.data.id,
      },
    }).then((res) => {
      this.setData({
        show1: res.show === 1,
      });
      if (res.show !== 1) {
        this.init();
      }
    });
  },
  onAgreeClose() {
    wx.navigateBack();
  },
  handleSubmitAgree() {
    wx.ajax({
      method: "POST",
      url: "?r=takeda/account/close-chat-room-notice",
      data: {},
    }).then(() => {
      this.setData({
        show1: false,
      });
      this.init();
    });
  },
  getDetail() {
    wx.ajax({
      method: "GET",
      url: "?r=takeda/chat/get-room-detail",
      data: { roomId: this.data.id },
    }).then((res) => {
      this.setData({
        roomDoctors: res.roomDoctors,
        newRoomDoctors: { ...res }.roomDoctors.slice(0, 4),
        case: res.case,
        chatGroupInfo: res.chatGroupInfo,
        chatDoctor: res.chatDoctor,
      });
      wx.setNavigationBarTitle({
        title: `学习窗(${res.roomDoctorCount})`,
      });
      this.getInvite();

      this.WebIMLogin();

      this.getCaseDetail();
    });
  },
  handleRoomDetail() {
    app.mpBehavior({ PageName: "BTN_CHATROOMAVATAR" });
    wx.navigateTo({
      url: `/module1/pages/chatRoomInfo/index?id=${this.data.id}&cid=${this.data.case.caseId}`,
    });
  },
  handleCaseDetail() {
    app.mpBehavior({ PageName: "BTN_CHATROOMCASEDETAIL" });
    wx.navigateTo({
      url: `/module1/pages/casesDetail/index?id=${this.data.case.caseId}&rid=${this.data.id}`,
    });
  },

  handleView(index = -1) {
    const time = setTimeout(() => {
      this.setData({
        scrollIntoView: index > -1 ? `view${index}` : `place`,
      });
      clearTimeout(time);
    }, 300);
  },
  getMessageList() {
    if (this.data.isLoad || this.data.isFinish) return;
    this.setData({
      isLoad: true,
    });
    const lastMsgId = this.data.lastMsgId;
    wx.ajax({
      method: "GET",
      url: "?r=takeda/chat/get-message-list",
      data: {
        lastMsgId,
        roomId: this.data.id,
      },
    }).then((res) => {
      if (res.length === 0) {
        this.setData({
          isFinite: true,
        });
        return;
      }
      res.map((item) => {
        return this.formatMessage(item);
      });
      this.setData({
        messageList: [...res.reverse(), ...this.data.messageList],
        lastMsgId: res[0].msgId,
        isLoad: false,
      });
      this.formatRecall();
      this.filterCreateTime();

      if (!lastMsgId) {
        this.handleView();
      }
    });
  },
  scrolltoupper(e) {
    if (e.detail.direction === "top") {
      this.getMessageList();
    }
  },
  handleSendMessage() {
    const { sendMessage, userInfo } = this.data;
    if (!sendMessage) {
      wx.showToast({
        icon: "none",
        title: "请输入内容",
      });
      return;
    }
    const message: IMessageItem = {
      msgId: "",
      contentType: "1",
      content: sendMessage,
      fromDoctorId: userInfo.DoctorId,
      createTime: dayjs().format("YYYY-MM-DD HH:mm:ss"),
      isSelf: 1,
      isRead: 2,
      doctorImg: userInfo.Img,
      doctorName: userInfo.Name,
      hospitalName: userInfo.HospitalName,
    };
    this.setData({
      sendMessage: "",
    });
    this.WebIMSendMessage(message);
  },
  handleSendMapAudio() {
    app.mpBehavior({ PageName: "BTN_CHATROOMRECORDLONGPRESS" });
  },
  handleSendAudio(e) {
    const { userInfo } = this.data;
    const contentStr = JSON.stringify({
      url: e.detail.fileUrl,
      duration: e.detail.duration,
    });
    const message: IMessageItem = {
      msgId: "",
      contentType: "2",
      content: contentStr,
      fromDoctorId: userInfo.DoctorId,
      createTime: dayjs().format("YYYY-MM-DD HH:mm:ss"),
      isSelf: 1,
      isRead: 2,
      doctorImg: userInfo.Img,
      doctorName: userInfo.Name,
      hospitalName: userInfo.HospitalName,
    };
    this.WebIMSendMessage(message);
  },
  handleSendMapPhoto() {
    app.mpBehavior({ PageName: "BTN_CHATROOMSELECTIMAGE" });
  },
  handleSendPhoto(e) {
    const { userInfo } = this.data;
    const contentStr = JSON.stringify({
      url: e.detail.fileUrl,
    });
    const message: IMessageItem = {
      msgId: "",
      contentType: "3",
      content: contentStr,
      fromDoctorId: userInfo.DoctorId,
      createTime: dayjs().format("YYYY-MM-DD HH:mm:ss"),
      isSelf: 1,
      isRead: 2,
      doctorImg: userInfo.Img,
      doctorName: userInfo.Name,
      hospitalName: userInfo.HospitalName,
    };
    this.WebIMSendMessage(message);
  },
  handleSendMapVideo() {
    app.mpBehavior({ PageName: "BTN_CHATROOMSELECTVIDEO" });
  },
  handleSendVideo(e) {
    const { userInfo } = this.data;
    const contentStr = JSON.stringify({
      url: e.detail.fileUrl,
      imgUrl: e.detail.imgUrl,
    });
    const message: IMessageItem = {
      msgId: "",
      contentType: "4",
      content: contentStr,
      fromDoctorId: userInfo.DoctorId,
      createTime: dayjs().format("YYYY-MM-DD HH:mm:ss"),
      isSelf: 1,
      isRead: 2,
      doctorImg: userInfo.Img,
      doctorName: userInfo.Name,
      hospitalName: userInfo.HospitalName,
    };
    this.WebIMSendMessage(message);
  },
  sendMessage({ uniqueCode, ...message }) {
    wx.ajax({
      method: "POST",
      url: "?r=takeda/chat/send-message",
      data: {
        roomId: this.data.id,
        message: {
          contentType: message.contentType,
          content: message.content,
          uniqueCode,
        },
      },
    });
  },
  handleRecall(e) {
    app.mpBehavior({ PageName: "BTN_CHATROOMREVOKE" });
    const { index } = e.currentTarget.dataset;
    const { messageList } = this.data;
    const message = messageList[index];
    this.senIMRecallMessage(message);
    this.delMessage(message);
    this.senRecallMessage(index);
  },
  delMessage(message) {
    const { id } = this.data;
    wx.ajax({
      method: "POST",
      url: "?r=takeda/chat/del-message",
      data: {
        roomId: id,
        msgId: message.msgId,
        uniqueCode: message.uniqueCode,
      },
    });
  },
  senRecallMessage(index) {
    const { userInfo, messageList } = this.data;
    const message: IMessageItem = {
      msgId: "",
      contentType: "6",
      content: "你撤回了一条消息",
      fromDoctorId: userInfo.DoctorId,
      createTime: dayjs().format("YYYY-MM-DD HH:mm:ss"),
      isSelf: 1,
      isRead: 2,
      doctorImg: userInfo.Img,
      doctorName: userInfo.Name,
      hospitalName: userInfo.HospitalName,
    };
    messageList.splice(index, 1, message);
    this.setData({
      messageList,
    });
  },
  senIMRecallMessage(message) {
    const { chatGroupInfo, userInfo } = this.data;
    const option = {
      mid: message.uniqueCode,
      to: chatGroupInfo.ChatGroupId,
      chatType: "groupChat",
      ext: userInfo.Name,
    };
    wx.WebIM.conn.recallMessage(option);
  },
  senRecallCallback(message) {
    const { messageList } = this.data;
    const { mid } = message;
    let mIndex: number | null = null;
    const newMessageList = messageList.filter((item, index) => {
      if (item.uniqueCode === mid) {
        mIndex = index;
        return false;
      }
      return true;
    });
    this.setData({
      messageList: newMessageList,
    });
    if (mIndex) {
      this.senRecallCallbackPush(mIndex, message);
    }
  },
  senRecallCallbackPush(index, extMessage) {
    const { userInfo, messageList } = this.data;
    const message: IMessageItem = {
      msgId: "",
      contentType: "6",
      content: `${extMessage.ext}撤回了一条消息`,
      fromDoctorId: userInfo.DoctorId,
      createTime: dayjs().format("YYYY-MM-DD HH:mm:ss"),
      isSelf: 1,
      isRead: 2,
      doctorImg: userInfo.Img,
      doctorName: userInfo.Name,
      hospitalName: userInfo.HospitalName,
    };
    messageList.splice(index, 1, message);
    this.setData({
      messageList,
    });
  },
  WebIMLogin() {
    const { chatDoctor } = this.data;
    wx.WebIM.conn
      .open({
        user: chatDoctor.chatUserId,
        pwd: chatDoctor.chatUserPwd,
      })
      .then(() => {
        this.listenMessage();
      });
  },
  WebIMSendMessage(message: IMessageItem) {
    const { chatGroupInfo } = this.data;
    const option = {
      type: "txt",
      msg: message.content,
      to: chatGroupInfo.ChatGroupId,
      chatType: "groupChat",
      deliverOnlineOnly: "true",
      ext: {
        ...message,
      },
    };
    const msg = wx.WebIM.message.create(option);
    wx.WebIM.conn
      .send(msg)
      .then((res) => {
        const uniqueCodeMessage = { ...message, uniqueCode: res.serverMsgId };
        this.sendMessage(uniqueCodeMessage);
        this.setData({
          messageList: [...this.data.messageList, this.formatMessage(uniqueCodeMessage)],
        });
        this.handleView();
      })
      .catch(() => {
        wx.showToast({
          icon: "none",
          title: "发送失败",
        });
      });
  },
  listenMessage() {
    const { chatGroupInfo } = this.data;
    wx.WebIM.conn.addEventHandler("room", {
      onTextMessage: (message) => {
        if (message.error) {
          return;
        }
        if (message.to === chatGroupInfo.ChatGroupId) {
          this.setData({
            messageList: [
              ...this.data.messageList,
              this.formatMessage({
                ...message.ext,
                uniqueCode: message.id,
                isSelf: 2,
              }),
            ],
          });
          this.formatRecall();
          this.handleReadAll();
          this.handleView();
        }
      },
      onRecallMessage: (message) => {
        this.senRecallCallback(message);
      },
    });
  },
  formatMessage(message: IMessageItem) {
    //消息内容类型，1-文本，2-语音，3-图片，4-视频，5-提示信息
    if (["2", "3", "4"].includes(message.contentType)) {
      message.content = JSON.parse(message.content);
    }
    return message;
  },
  formatTime(date: string) {
    let createTimeName = "";
    if (dayjs().format("YYYY-MM-DD") === dayjs(date).format("YYYY-MM-DD")) {
      createTimeName = dayjs(date).format("HH:mm");
    } else if (dayjs().format("YYYY-MM-DD") === dayjs(date).add(1, "day").format("YYYY-MM-DD")) {
      createTimeName = `昨天 ${dayjs(date).format("HH:mm")}`;
    } else if (dayjs().diff(date, "day") < 7) {
      createTimeName = dayjs(date).format(`dddd HH:mm`);
    } else {
      createTimeName = dayjs(date).format("YYYY-MM-DD HH:mm");
    }
    return createTimeName;
  },
  filterCreateTime() {
    const gapTime = 5 * 60 * 1000;
    const { messageList } = this.data;

    let preTime = 0;
    messageList.forEach((item, index) => {
      if (index === 0) {
        item.showTime = true;
        preTime = dayjs(item.createTime).valueOf();
        item.createTimeName = this.formatTime(item.createTime);
      } else {
        const curTime = dayjs(item.createTime).valueOf();
        if (curTime - preTime > gapTime) {
          item.showTime = true;
          item.createTimeName = this.formatTime(item.createTime);
          preTime = dayjs(item.createTime).valueOf();
        }
      }
    });
    this.setData({
      messageList,
    });
  },
  formatRecall() {
    const { messageList } = this.data;
    messageList.forEach((item) => {
      // if (item.contentType === "6" && item.isSelf === 2) {
      //   item.content = `"${item.doctorName}"撤回了一条消息`;
      // }
      if (item.contentType === "6" && item.isSelf === 1) {
        item.content = `你撤回了一条消息`;
      }
    });
    this.setData({
      messageList,
    });
  },
  handleFooter() {
    app.mpBehavior({ PageName: "BTN_CHATROOMMOREOPTIONS" });
    this.setData({
      fold: !this.data.fold,
    });
    if (!this.data.fold) {
      this.handleView();
    }
  },
  handleAudio(e) {
    const { index } = e.currentTarget.dataset;
    const { messageList } = this.data;
    const messageItem = messageList[index];
    const { url } = messageItem.content;
    if (this.innerAudioContext) {
      if (messageItem.isPlay) {
        this.innerAudioContext.stop();
        messageItem.isPlay = false;
        this.setData({
          messageList,
        });
        return;
      }
      this.innerAudioContext.stop();
      this.innerAudioContext.src = url;
      this.innerAudioContext.play();
      messageItem.isPlay = true;
      if (messageItem.isRead === 2 && messageItem.isSelf === 2) {
        messageItem.isRead = 1;
        this.handleReadAudio({
          msgId: messageItem.msgId,
          uniqueCode: messageItem.uniqueCode,
        });
      }
      this.innerAudioContext.onEnded(() => {
        messageItem.isPlay = false;
        this.setData({
          messageList,
        });
      });
      this.innerAudioContext.onStop(() => {
        messageItem.isPlay = false;
        this.setData({
          messageList,
        });
      });
      this.setData({
        messageList,
      });
    }
  },
  handleReadAudio({ msgId, uniqueCode }) {
    wx.ajax({
      method: "POST",
      url: "?r=takeda/chat/read-message",
      data: {
        roomId: this.data.id,
        msgId,
        uniqueCode,
      },
    });
  },
  handlePreview(e) {
    const { url } = e.currentTarget.dataset;
    wx.previewImage({
      urls: [url],
    });
  },
  handleVideo(e) {
    const { url } = e.currentTarget.dataset;
    if (this.videoContext) {
      this.setData({
        videoUrl: url,
      });
      this.videoContext.play();
      this.videoContext.requestFullScreen({});
    }
  },

  handleReadAll() {
    wx.ajax({
      method: "POST",
      url: "?r=takeda/chat/read-all-message",
      data: { roomId: this.data.id },
    });
  },
  handleFocus() {
    this.setData({
      focus: true,
    });
  },
  handleBlur() {
    this.setData({
      focus: false,
    });
  },
  handleToggleRecord() {
    if (!this.data.record) {
      app.mpBehavior({ PageName: "BTN_CHATROOMVOICE" });
    }
    this.setData({
      record: !this.data.record,
      focus: !this.data.record,
    });
  },
  handleLongpress(e) {
    const { index } = e.currentTarget.dataset;
    const { messageList } = this.data;
    if (["1", "2", "3", "4"].includes(messageList[index].contentType)) {
      messageList[index].longpress = true;
      this.setData({
        messageList,
      });
    }
  },
  handleNoLongPress() {
    const { messageList } = this.data;
    messageList.map((item) => {
      item.longpress = false;
      return item;
    });
    this.setData({
      messageList,
    });
  },
  handleConformSendCase() {
    this.setData({
      show2: true,
    });
  },
  handleCancelSendCase() {
    this.setData({
      show2: false,
    });
  },
  handleSendCase() {
    const { userInfo } = this.data;
    const message: IMessageItem = {
      msgId: "",
      contentType: "7",
      content: "病历",
      fromDoctorId: userInfo.DoctorId,
      createTime: dayjs().format("YYYY-MM-DD HH:mm:ss"),
      isSelf: 1,
      isRead: 2,
      doctorImg: userInfo.Img,
      doctorName: userInfo.Name,
      hospitalName: userInfo.HospitalName,
    };
    this.WebIMSendMessage(message);
    this.handleCancelSendCase();
  },

  handleCase() {
    this.setData({
      show3: true,
    });
  },
  handleCaseDetailClose() {
    this.setData({
      show3: false,
    });
  },
  getCaseDetail() {
    wx.ajax({
      method: "GET",
      url: "?r=takeda/case/get-case-detail",
      data: {
        caseId: this.data.case.caseId,
      },
    }).then((res) => {
      res.feedbackList.map((item) => {
        item.fold = false;
        return item;
      });
      this.setData({
        detail: res,
        dealDoctorInfo: res.dealCaseInfo.dealDoctorInfo,
        dealInfo: res.dealCaseInfo.dealInfo,
        deptId: res.caseDeptId[0],
        labelIds: res.caseLabels.map((item) => item.labelId),
      });
    });
  },
  handleFold() {
    this.setData({
      caseFold: !this.data.caseFold,
    });
  },
  handleFeedBackFold(e) {
    const { index } = e.currentTarget.dataset;
    const { detail } = this.data;
    const feedbackList = detail.feedbackList;
    feedbackList[index].fold = !feedbackList[index].fold;
    this.setData({
      detail: {
        ...detail,
        feedbackList,
      },
    });
  },
  handlePreviewFile(e) {
    app.mpBehavior({ PageName: "BTN_CASEDETAILFILEPREVIEW" });
    const { item } = e.currentTarget.dataset;
    wx.downloadFile({
      url: item.url,
      success(res) {
        wx.openDocument({
          filePath: res.tempFilePath,
          showMenu: true,
          fail() {
            wx.showToast({
              title: "该文件无法预览",
              icon: "none",
            });
          },
        });
      },
    });
  },
  handlePreviewName(e) {
    const { item } = e.currentTarget.dataset;
    wx.showModal({
      title: "文件名",
      content: item.name,
      confirmColor: "#00B4C5",
      cancelColor: "#141515",
      showCancel: false,
      confirmText: "关闭",
    });
  },
  handleImagePreview(e) {
    const { index, parent } = e.currentTarget.dataset;
    const sources = parent.map((item) => {
      return {
        url: item.fileType == 3 ? item.videoUrl : item.url,
        type: item.fileType == 3 ? 'video' : 'image',
      };
    });
    wx.previewMedia({
      sources,
      current: index,
    });
  },
});
