const app = getApp<IAppOption>();

Page({
  data: {
    DepartmentId: "",
    DepartmentName: "",
    Department: [],

    doctorCount: {},

    tree: [] as any,
    search: "",

    userInfo: {} as any,

    allFold: false,
  },
  onLoad() {
    app.waitLogin().then(() => {
      app.getUserInfo(this, (userInfo) => {
        const { DepartmentId, DepartmentName } = userInfo.Department[0];
        this.setData({
          Department: userInfo.Department,
          DepartmentId,
          DepartmentName,
        });
        this.getManageDoctor();
        this.getTree();
      });
    });
  },
  getManageDoctor() {
    wx.ajax({
      method: "GET",
      url: "?r=takeda/doctor/manage-doctor-count",
      data: { DepartmentId: this.data.DepartmentId },
    }).then((res) => {
      this.setData({
        doctorCount: res.count,
      });
    });
  },
  getTree() {
    wx.ajax({
      method: "GET",
      url: "?r=takeda/doctor/doctor-tree-list",
      data: { DepartmentId: this.data.DepartmentId },
    }).then((res) => {
      this.setData({
        tree: res.tree,
      });
    });
  },
  handleChange(e) {
    const index = e.detail.value;
    const { DepartmentId, DepartmentName } = this.data.Department[index];
    this.setData({
      DepartmentId,
      DepartmentName,
    });
    this.getManageDoctor();
    this.getTree();
  },
  handleInvite() {
    wx.navigateTo({
      url: "/module1/pages/invite/index",
    });
  },
  handleSearch() {
    const { tree, search } = this.data;
    let newTree: any = null;
    if (search) {
      newTree = this.sourceTree(tree, search);
    } else {
      newTree = this.clearTree(tree, search);
    }
    this.setData({
      tree: newTree,
    });
  },
  sourceTree(tree: any[], search: string): any[] {
    return tree.map((item) => {
      if (item.Children?.length) {
        this.sourceTree(item.Children, search);
      }
      if (item.DoctorInfo.doctorName.includes(search)) {
        item.active = true;
      } else {
        item.active = false;
      }
      return item;
    });
  },
  clearTree(tree: any[], search: string): any[] {
    return tree.map((item) => {
      if (item.Children?.length) {
        this.clearTree(item.Children, search);
      }
      item.active = false;
      return item;
    });
  },
  handleFold(e) {
    const { index } = e.currentTarget.dataset;
    const { tree } = this.data;
    tree[index].fold = !tree[index].fold;
    this.setData({
      tree,
    });
  },
  handleSubFold(e) {
    const { index, subindex } = e.currentTarget.dataset;
    const { tree } = this.data;
    tree[index].Children[subindex].fold = !tree[index].Children[subindex].fold;
    this.setData({
      tree,
    });
  },
  handleFoldAll() {
    const { tree, allFold } = this.data;
    const newTree = this.toggleFoldAll(tree, !allFold);
    this.setData({
      allFold: !allFold,
      tree: newTree,
    });
  },
  toggleFoldAll(tree, fold) {
    return tree.map((item) => {
      if (item.Children?.length) {
        this.toggleFoldAll(item.Children, fold);
      }
      item.fold = fold;
      return item;
    });
  },
  handleDoctrDetail(e) {
    const { id } = e.currentTarget.dataset;
    wx.navigateTo({
      url: `/module1/pages/doctorHome/index?id=${id}`,
    });
  },
});

export {};
