import { parseScene } from "@/utils/util";
const app = getApp<IAppOption>();

Page({
  data: {
    applyDoctorInfo: null,
    applyHostipalInfo: null,
    InviteDoctorName: "",
    RejectReason: "",
    DoctorLevel: {},
    DoctorTitleType: {},

    AuditId: "",
    Name: "",
    HospitalId: "",
    TitleType: "",
    OtherTitle: "",
    InviteDoctorId: "",
    Img: "",
    QualificationImg: "",
    RegisterImg: "",
    PositionImg: "",
  },
  onLoad() {
    app.waitLogin(true).then(() => {
      app.mpBehavior({ PageName: "PG_DOCTORREGISTRATION" });
      this.getApplyDoctor();
      this.getLoastApplyHostipal();
      this.getDoctorDict();
      const doctorId = app.globalData.scene?.doctorId;

      if (doctorId) {
        this.getDoctorInfo(doctorId);
      }
    });
  },
  getApplyDoctor() {
    app.getApplyDoctor().then((res) => {
      if (!Array.isArray(res)) {
        this.setData({
          applyDoctorInfo: res,

          InviteDoctorName: res.InviteDoctorName,
          HospitalName: res.HospitalName,

          AuditId: res.AuditStatus === 1 ? 0 : res.AuditId,
          Name: res.Name,
          HospitalId: res.HospitalId,
          TitleType: `${res.TitleType}`,
          OtherTitle: res.OtherTitle,
          InviteDoctorId: res.InviteDoctorId,
          Img: res.Img,
          QualificationImg: res.QualificationImg,
          RegisterImg: res.RegisterImg,
          PositionImg: res.PositionImg,

          RejectReason: res.AuditStatus === 2 ? res.RejectReason : "",
        });
      }
    });
  },
  getDoctorInfo(dId) {
    wx.ajax({
      method: "GET",
      url: "?r=takeda/reg/doctor-info",
      data: {
        DoctorId: dId,
      },
    }).then((res) => {
      this.setData({
        InviteDoctorName: res.Name,
        InviteDoctorId: dId,
      });
    });
  },
  getLoastApplyHostipal() {
    wx.ajax({
      method: "GET",
      url: "?r=takeda/reg/last-apply-hospital",
      data: {},
    }).then((res) => {
      this.setData({
        applyHostipalInfo: Array.isArray(res) ? null : res,
      });
      if (res.AuditStatus === 1) {
        this.setData({
          HospitalName: res.Name,
          HospitalId: res.HospitalId,
        });
      }
    });
  },
  getDoctorDict() {
    wx.ajax({
      method: "GET",
      url: "?r=takeda/reg/doctor-dict",
      data: {},
    }).then((res) => {
      this.setData({
        DoctorLevel: res.DoctorLevel,
        DoctorTitleType: res.DoctorTitleType,
      });
    });
  },
  handleFile(e) {
    const { key } = e.currentTarget.dataset;
    this.setData({
      [key]: e.detail.imgUrl,
    });
  },
  handleHostipal() {
    wx.navigateTo({
      url: "/module1/pages/sHostipal/index?reg=1",
      events: {
        acceptDataFromOpenedPage: (data) => {
          this.setData({
            HospitalId: data.hid,
            HospitalName: data.hname,
          });
        },
      },
      success: () => {},
    });
  },
  handleTitleType(e) {
    const { value } = e.currentTarget.dataset;
    this.setData({
      TitleType: value,
    });
  },
  handleSubmitConform() {
    // app.mpBehavior({ PageName: "BTN_DOCTORREGISTRATIONSUBMIT" });
    wx.showModal({
      content: "您没有邀约医生，可能会影响您的审核",
      confirmColor: "#00B4C5",
      cancelColor: "#141515",
      confirmText: "绑定医生",
      cancelText: "取消",
      success: (res) => {
        if (res.confirm) {
          this.handleBindDoctor();
        }
      },
    });
  },
  handleSubmit() {
    // app.mpBehavior({ PageName: "BTN_DOCTORREGISTRATIONSUBMIT" });
    const {
      AuditId,
      Name,
      HospitalId,
      TitleType,
      OtherTitle,
      InviteDoctorId,
      Img,
      QualificationImg,
      RegisterImg,
      PositionImg,
    } = this.data;

    if (!Name) {
      wx.showToast({
        title: "请输入姓名",
        icon: "none",
      });
      return;
    }
    if (!HospitalId) {
      wx.showToast({
        title: "请选择医院",
        icon: "none",
      });
      return;
    }
    if (!TitleType) {
      wx.showToast({
        title: "请选择头衔",
        icon: "none",
      });
      return;
    }
    if (TitleType === "99" && !OtherTitle) {
      wx.showToast({
        title: "请输入自定义头衔",
        icon: "none",
      });
      return;
    }
    if (!RegisterImg) {
      wx.showToast({
        icon: "none",
        title: "请上传注册证",
      });
      return;
    }
    if (!QualificationImg) {
      wx.showToast({
        title: "请上传从业资格证",
        icon: "none",
      });
      return;
    }
    if (!PositionImg) {
      wx.showToast({
        title: "请上传任职证书",
        icon: "none",
      });
      return;
    }
    wx.ajax({
      method: "POST",
      url: "?r=takeda/reg/apply-doctor",
      data: {
        AuditId,
        Name,
        HospitalId,
        TitleType,
        OtherTitle,
        InviteDoctorId,
        Img,
        QualificationImg,
        RegisterImg,
        PositionImg,
      },
    }).then((res) => {
      app.globalData.scene = null;
      wx.reLaunch({
        url: `/module1/pages/setInfoResult/index?isf=${res.isFollow}&iname=${res.InviteDoctorName}`,
      });
    });
  },
  handleChangeHostipal() {
    wx.navigateTo({
      url: "/module1/pages/cHostipal/index",
    });
  },
  handleScan() {
    wx.showModal({
      confirmColor: "#00B4C5",
      cancelColor: "#141515",
      confirmText: "继续",
      title: " 扫描已入驻医生的邀约码 ",
      content: "绑定成功后，医生可审核您的入驻申请 ",
      success: (res) => {
        if (res.confirm) {
          wx.scanCode({
            success: (res) => {
              if (res.errMsg === "scanCode:ok") {
                if (res.path.includes("pages/start/index")) {
                  const scene: any = parseScene(res.path?.split("?scene=")[1]);
                  if (scene?.doctorId) {
                    app.globalData.scene = scene;
                    this.getDoctorInfo(scene.doctorId as string);
                    wx.showToast({
                      title: "扫码成功",
                      icon: "none",
                    });
                  } else {
                    wx.showToast({
                      title: "扫码失败",
                      icon: "none",
                    });
                  }
                } else {
                  wx.showToast({
                    title: "扫码失败",
                    icon: "none",
                  });
                }
              } else {
                wx.showToast({
                  title: "扫码失败",
                  icon: "none",
                });
              }
            },
            fail() {
              wx.showToast({
                title: "扫码失败",
                icon: "none",
              });
            },
          });
        }
      },
    });
  },
  handleBindDoctor() {
    wx.navigateTo({
      url: "/module1/pages/setInfoDoctor/index",
      events: {
        acceptDataFromOpenedPage: (data) => {
          this.setData({
            InviteDoctorId: data.DoctorId,
            InviteDoctorName: data.DoctorName,
          });
        },
      },
    });
  },
  handleLoginOut() {
    app.mpBehavior({ PageName: "BTN_DOCTORREGISTRATIONLOGOUT" });
    wx.showModal({
      confirmColor: "#00B4C5",
      cancelColor: "#141515",
      title: "确认退出登录？",
      success(res) {
        if (res.confirm) {
          app.globalData.isLogin = 0;
          wx.ajax({
            method: "POST",
            url: "?r=takeda/account/reg-logout",
          }).then(() => {
            wx.reLaunch({
              url: "/module1/pages/login/index",
            });
          });
        }
      },
    });
  },
});

export {};
